# image_processing

Description. 
The package image_processing is used to:
	Processing:
		- Histogram matching;
		- Structural similarity;
		- Resize Image.
	Utils:
		- Read Image;
		- Save Iamge,
		- Plot image;
		- Plot result;
		- Plot histogram.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install image-processing 
```

## Author
Lucas Melo

## License
[MIT](https://choosealicense.com/licenses/mit/)